@@ -40,7 +40,7 @@ namespace Rcpp {
 		default:
 			throw not_compatible("cannot convert to function") ;
 		}
-	};
+	}
 	
 	Function::Function(const std::string& name) throw(no_such_function) : RObject() {
 		SEXP x = PROTECT( Rf_findFun( Rf_install(name.c_str()), R_GlobalEnv ) ) ;
@@ -66,4 +66,8 @@ namespace Rcpp {
 		return CLOENV(m_sexp) ;
 	}
 	
+	SEXP Function::body() const {
+		return BODY( m_sexp ) ;
+	}
+	
 } // namespace Rcpp
